@@ -1,4 +1,4 @@
-from datetime import date
+from datetime import date, datetime
 import enum
 from io import StringIO
 import logging
@@ -6,7 +6,6 @@ from typing import Any, Dict, Iterable, List, Optional
 
 import pandas as pd
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -39,6 +38,8 @@ def process_bool_parameter(parameter: Optional[bool]) -> Optional[str]:
 def process_date_parameter(parameter: Optional[date]) -> Optional[str]:
     return parameter.isoformat() if parameter else None
 
+def process_snapshot_date_parameter(parameter: Optional[datetime]) -> Optional[str]:
+    return parameter.strftime('%Y-%m-%d %H:%M:%S') if parameter else None
 
 def process_enum_parameters(
     parameter: Optional[List[enum.Enum]], to_lower_case: bool = True
