@@ -43,6 +43,8 @@ class Flows(KplerClient):
         with_intra_country: Optional[bool] = None,
         with_forecast: Optional[bool] = None,
         with_freight_view: bool = False,
+        vessel_types: Optional[List[str]] = None,
+        vessel_types_alt: Optional[List[str]] = None,
     ):
         """
 
@@ -62,6 +64,8 @@ class Flows(KplerClient):
              with_intra_country: Optional[bool] By default: withIntraCountry=false. Takes into account the trades within the selected region. Use ["true", "false"]
              with_forecast: Optional[bool] By default: withForecast=true. Include trades predicted by our in-house model when set to "true". Use ["true", "false"]
              with_freight_view: bool By default: with_freight_view=False. Provides access to the entire fleet's trades, irrespective of your current cargo subscription. Only available via Freight subscription.
+            vessel_types: Optional[List[str]] = Names of vessel types
+            vessel_types_alt: Optional[List[str]] = Names of vessel types for oil liquids platform only
 
         Examples:
 
@@ -106,5 +110,7 @@ class Flows(KplerClient):
             "withIntraCountry": process_bool_parameter(with_intra_country),
             "withForecast": process_bool_parameter(with_forecast),
             "withFreightView": process_bool_parameter(with_freight_view),
+            "vesselTypes": process_enum_parameters(vessel_types, to_lower_case=False),
+            "vesselTypesAlt": process_enum_parameters(vessel_types_alt, to_lower_case=False),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
